@@ -6,7 +6,7 @@ use 5.010001;
 use Role::Tiny::With;
 
 # ABSTRACT: Disable accounts which belong to a group
-our $VERSION = '0.30'; # VERSION
+our $VERSION = '0.31'; # VERSION
 
 
 with 'PlugAuth::Role::Plugin';
@@ -29,21 +29,27 @@ sub init
 sub check_credentials
 {
   my($self, $user, $pass) = @_;
-  return 0 if grep { lc($_) eq $self->{group} } @{ $self->app->authz->groups_for_user($user) };
+  my $groups = $self->app->authz->groups_for_user($user);
+  return 0 unless $groups;
+  return 0 if grep { lc($_) eq $self->{group} } @$groups;
   $self->deligate_check_credentials($user, $pass);
 }
 
 1;
+
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 PlugAuth::Plugin::DisableGroup - Disable accounts which belong to a group
 
 =head1 VERSION
 
-version 0.30
+version 0.31
 
 =head1 SYNOPSIS
 
@@ -92,4 +98,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
