@@ -1,7 +1,7 @@
 package PlugAuth::Plugin::FlatAuth;
 
 # ABSTRACT: Authentication using Flat Files for PlugAuth
-our $VERSION = '0.30'; # VERSION
+our $VERSION = '0.31'; # VERSION
 
 
 use strict;
@@ -52,7 +52,13 @@ sub refresh {
 sub _validate_pw
 {
   my($plain, $encrypted) = @_;
-  return 1 if crypt($plain, $encrypted) eq $encrypted;
+  return 1 if do {
+    # crypt on an apache apr1 encrypted
+    # password seems to return undef
+    # on Debian 8 (probably others)
+    my $ret = crypt($plain, $encrypted);
+    (defined $ret) && ($ret eq $encrypted);
+  };
     
   # idea borrowed from Authen::Simple::Password
   if($encrypted =~ /^\$(\w+)\$/)
@@ -241,17 +247,19 @@ sub delete_user
 
 1;
 
-
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 PlugAuth::Plugin::FlatAuth - Authentication using Flat Files for PlugAuth
 
 =head1 VERSION
 
-version 0.30
+version 0.31
 
 =head1 SYNOPSIS
 
@@ -336,8 +344,6 @@ Delete the given user.
 
 L<PlugAuth>, L<PlugAuth::Plugin::FlatAuthz>
 
-=cut
-
 =head1 AUTHOR
 
 Graham Ollis <gollis@sesda3.com>
@@ -350,4 +356,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
